# pydlutils
--------------------------------------------------------------------------------

## About
python utils library for deep learning, computer vision, LLM, slam or other python related job.

## Module instruction

1. basic
    place the basic module, type definition, utility function.

2. third party
    place modules which come from other repositories.

3. torch
    place torch related high level api.

## Build and Upload
```
# build
python setup.py sdist bdist_wheel
# upload
twine upload dist/*
```

## Publications
```
@software{pydlutils,
  author = {zebincai},
  title = {pydlutils},
  url = {\url{https://github.com/zebincai/pydlutils}},
}
```
## License
pydlutils has a Apache license, as found in the [LICENSE](LICENSE) file.
